@@ -1,29 +1,25 @@
-# coding: utf-8
-
 """
     CoCo config
     ================
 
     :created: 2014 by Jens Diemer - www.jensdiemer.de
-    :copyleft: 2014 by the DragonPy team, see AUTHORS for more details.
+    :copyleft: 2014-2015 by the DragonPy team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
 
 import logging
-import os
 
 from dragonlib.api import CoCoAPI
-import logging
 
-log=logging.getLogger(__name__)
+from dragonpy.CoCo.CoCo2b_rom import CoCo2b_Basic13_ROM, CoCo2b_ExtendedBasic11_ROM
 from dragonpy.CoCo.mem_info import get_coco_meminfo
+from dragonpy.core.configs import COCO2B
 from dragonpy.Dragon32.config import Dragon32Cfg
 from dragonpy.Dragon32.keyboard_map import get_coco_keymatrix_pia_result
-from dragonpy.components.rom import ROMFile
-from dragonpy.core.configs import COCO2B
+
+
+log = logging.getLogger(__name__)
 
 
 class CoCo2bCfg(Dragon32Cfg):
@@ -45,7 +41,7 @@ class CoCo2bCfg(Dragon32Cfg):
 #     RAM_END = 0x0FFF # 4KB # BASIC will always raise a OM ERROR!
 #     RAM_END = 0x1FFF # 8KB # BASIC will always raise a OM ERROR!
 #     RAM_END = 0x3FFF # 16KB # usable
-    RAM_END = 0x7FFF # 32KB
+    RAM_END = 0x7FFF  # 32KB
 
     ROM_START = 0x8000
     ROM_END = 0xFFFF
@@ -58,27 +54,19 @@ class CoCo2bCfg(Dragon32Cfg):
     """
     ROM_START = 0x8000
     DEFAULT_ROMS = (
-        ROMFile(address=0x8000, max_size=0x4000,
-            filepath=os.path.join(os.path.abspath(os.path.dirname(__file__)),
-                "extbas11.rom"
-            )
-        ),
-        ROMFile(address=0xA000, max_size=0x4000,
-            filepath=os.path.join(os.path.abspath(os.path.dirname(__file__)),
-                "bas13.rom"
-            )
-        ),
+        CoCo2b_ExtendedBasic11_ROM(address=0x8000, max_size=0x4000),
+        CoCo2b_Basic13_ROM(address=0xA000, max_size=0x4000),
     )
 
     def __init__(self, cmd_args):
-        super(CoCo2bCfg, self).__init__(cmd_args)
+        super().__init__(cmd_args)
 
         self.machine_api = CoCoAPI()
 
         if self.verbosity <= logging.ERROR:
             self.mem_info = get_coco_meminfo()
 
-        self.periphery_class = None# Dragon32Periphery
+        self.periphery_class = None  # Dragon32Periphery
 
         self.memory_byte_middlewares = {
             # (start_addr, end_addr): (read_func, write_func)
@@ -120,24 +108,4 @@ class CoCo2bCfg(Dragon32Cfg):
 config = CoCo2bCfg
 
 
-#------------------------------------------------------------------------------
-
-
-def test_run():
-    import sys
-    import os
-    import subprocess
-    cmd_args = [
-        sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-#        "--verbosity", "5",
-#        "--machine", "Dragon32", "run",
-        "--machine", "CoCo2b", "run",
-#        "--max_ops", "1",
-#        "--trace",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
+# ------------------------------------------------------------------------------
