@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# encoding:utf8
 
 """
     DragonPy - Dragon 32 emulator in Python
@@ -18,24 +17,19 @@
     Based on: XRoar emulator by Ciaran Anscomb (GPL license) more info, see README
 """
 
-from __future__ import absolute_import, division, print_function
-
-import os
-
-try:
-    import queue # Python 3
-except ImportError:
-    import Queue as queue # Python 2
 
 import logging
+import queue
 
-log=logging.getLogger(__name__)
 from dragonpy.core.configs import COCO2B
-from dragonpy.utils.bits import is_bit_set, invert_byte, clear_bit, set_bit
+from dragonpy.utils.bits import is_bit_set, set_bit
 from dragonpy.utils.humanize import byte2bit_string
 
 
-class PIA_register(object):
+log = logging.getLogger(__name__)
+
+
+class PIA_register:
 
     def __init__(self, name):
         self.name = name
@@ -51,7 +45,7 @@ class PIA_register(object):
         self.irq = 0x00
 
     def set(self, value):
-        log.debug("\t set %s to $%02x %s", self.name, value, '{0:08b}'.format(value))
+        log.debug("\t set %s to $%02x %s", self.name, value, f'{value:08b}')
         self.value = value
 
     def get(self):
@@ -69,7 +63,7 @@ class PIA_register(object):
         self._pdr_selected = False
 
 
-class PIA(object):
+class PIA:
     """
     PIA - MC6821 - Peripheral Interface Adaptor
 
@@ -91,6 +85,7 @@ class PIA(object):
     $ff22 PIA 1 B side Data register         PB7
     $ff23 PIA 1 B side Control register      CB1
     """
+
     def __init__(self, cfg, cpu, memory, user_input_queue):
         self.cfg = cfg
         self.cpu = cpu
@@ -179,7 +174,7 @@ class PIA(object):
         log.error("TODO: read from 0xff23 -> PIA 1 B side Control reg.")
         return 0x37
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
     def write_PIA1_A_data(self, cpu_cycles, op_address, address, value):
         """ write to 0xff20 -> PIA 1 A side Data reg. """
@@ -202,7 +197,7 @@ class PIA(object):
         log.error(
             "TODO: write $%02x to 0xff23 -> PIA 1 B side Control reg.", value)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
     def read_serial_interface(self, cpu_cycles, op_address, address):
         log.error("TODO: read from $%04x (D64 serial interface", address)
@@ -212,7 +207,7 @@ class PIA(object):
         log.error(
             "TODO: write $%02x to $%04x (D64 serial interface", value, address)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # Keyboard matrix on PIA0
 
     def read_PIA0_A_data(self, cpu_cycles, op_address, address):
@@ -228,11 +223,11 @@ class PIA(object):
         bit 1 | PA1 | keyboard matrix row 2 & left  joystick switch 1
         bit 0 | PA0 | keyboard matrix row 1 & right joystick switch 1
         """
-        pia0b = self.pia_0_B_data.get()  # $ff02
+        pia0b = self.pia_0_B_data.value  # $ff02
 
         # FIXME: Find a way to handle CoCo and Dragon in the same way!
         if self.cfg.CONFIG_NAME == COCO2B:
-#            log.critical("\t count: %i", self.input_repead)
+            #            log.critical("\t count: %i", self.input_repead)
             if self.input_repead == 7:
                 try:
                     self.current_input_char = self.user_input_queue.get_nowait()
@@ -242,7 +237,7 @@ class PIA(object):
                     log.critical(
                         "\tget new key from queue: %s", repr(self.current_input_char))
             elif self.input_repead == 18:
-#                log.critical("\tForce send 'no key pressed'")
+                #                log.critical("\tForce send 'no key pressed'")
                 self.current_input_char = None
             elif self.input_repead > 20:
                 self.input_repead = 0
@@ -269,18 +264,20 @@ class PIA(object):
                     try:
                         self.current_input_char = self.user_input_queue.get_nowait()
                     except queue.Empty:
-#                        log.critical("\tinput_queue is empty"))
+                        # log.critical("\tinput_queue is empty"))
                         self.current_input_char = None
                     else:
-#                        log.critical("\tget new key from queue: %s", repr(self.current_input_char))
+                        # log.critical(
+                        #     "\tget new key from queue: %s", repr(self.current_input_char)
+                        # )
                         self.empty_key_toggle = True
 
         if self.current_input_char is None:
-#            log.critical("\tno key pressed")
+            #            log.critical("\tno key pressed")
             result = 0xff
             self.empty_key_toggle = False
         else:
-#            log.critical("\tsend %s", repr(self.current_input_char))
+            #            log.critical("\tsend %s", repr(self.current_input_char))
             result = self.cfg.pia_keymatrix_result(
                 self.current_input_char, pia0b)
 
@@ -301,9 +298,9 @@ class PIA(object):
     def write_PIA0_A_data(self, cpu_cycles, op_address, address, value):
         """ write to 0xff00 -> PIA 0 A side Data reg. """
         log.error("%04x| write $%02x (%s) to $%04x -> PIA 0 A side Data reg.\t|%s",
-            op_address, value, byte2bit_string(value), address,
-            self.cfg.mem_info.get_shortest(op_address)
-        )
+                  op_address, value, byte2bit_string(value), address,
+                  self.cfg.mem_info.get_shortest(op_address)
+                  )
         self.pia_0_A_register.set(value)
 
     def read_PIA0_A_control(self, cpu_cycles, op_address, address):
@@ -358,7 +355,7 @@ class PIA(object):
 
         bits 0-7 also printer data lines
         """
-        value = self.pia_0_B_data.get()  # $ff02
+        value = self.pia_0_B_data.value  # $ff02
         log.debug(
             "%04x| read $%04x (PIA 0 B side Data reg.) send $%02x (%s) back.\t|%s",
             op_address, address, value, byte2bit_string(value),
@@ -369,7 +366,7 @@ class PIA(object):
     def write_PIA0_B_data(self, cpu_cycles, op_address, address, value):
         """ write to 0xff02 -> PIA 0 B side Data reg. """
         log.debug(
-#        log.info(
+            #        log.info(
             "%04x| write $%02x (%s) to $%04x -> PIA 0 B side Data reg.\t|%s",
             op_address, value, byte2bit_string(value),
             address, self.cfg.mem_info.get_shortest(op_address)
@@ -380,7 +377,7 @@ class PIA(object):
         """
         read from 0xff03 -> PIA 0 B side Control reg.
         """
-        value = self.pia_0_B_control.get()
+        value = self.pia_0_B_control.value
         log.error(
             "%04x| read $%04x (PIA 0 B side Control reg.) send $%02x (%s) back.\t|%s",
             op_address, address, value, byte2bit_string(value),
@@ -432,29 +429,4 @@ class PIA(object):
 
         self.pia_0_B_control.set(value)
 
-#------------------------------------------------------------------------------
-
-
-def test_run():
-    import sys
-    import os
-    import subprocess
-    cmd_args = [
-        sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-#        "--verbosity", " 1", # hardcode DEBUG ;)
-#        "--verbosity", "10", # DEBUG
-#        "--verbosity", "20", # INFO
-#        "--verbosity", "30", # WARNING
-        "--verbosity", "40", # ERROR
-#        "--verbosity", "50", # CRITICAL/FATAL
-        "--machine", "Dragon32", "run",
-#        "--machine", "Vectrex", "run",
-#        "--max_ops", "1",
-#        "--trace",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
+# ------------------------------------------------------------------------------
