@@ -1,29 +1,24 @@
-# coding: utf-8
-
 """
     DragonPy - Dragon 32 emulator in Python
     =======================================
 
-    :created: 2013-2014 by Jens Diemer - www.jensdiemer.de
-    :copyleft: 2013-2014 by the DragonPy team, see AUTHORS for more details.
+    :created: 2013 by Jens Diemer - www.jensdiemer.de
+    :copyleft: 2013-2015 by the DragonPy team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-from dragonlib.utils import six
-xrange = six.moves.xrange
 
 import logging
-import os
 
 from dragonlib.api import Dragon32API
-import logging
 
-log=logging.getLogger(__name__)
+from dragonpy.core.configs import DRAGON32, BaseConfig
+from dragonpy.Dragon32.Dragon32_rom import Dragon32Rom
 from dragonpy.Dragon32.keyboard_map import get_dragon_keymatrix_pia_result
 from dragonpy.Dragon32.mem_info import get_dragon_meminfo
-from dragonpy.components.rom import ROMFile
-from dragonpy.core.configs import BaseConfig, DRAGON32
+
+
+log = logging.getLogger(__name__)
 
 
 class Dragon32Cfg(BaseConfig):
@@ -50,7 +45,7 @@ class Dragon32Cfg(BaseConfig):
 #     RAM_END = 0x0FFF # 4KB # BASIC will always raise a OM ERROR!
 #     RAM_END = 0x1FFF # 8KB # BASIC will always raise a OM ERROR!
 #     RAM_END = 0x3FFF # 16KB # usable
-    RAM_END = 0x7FFF # 32KB
+    RAM_END = 0x7FFF  # 32KB
 
     ROM_START = 0x8000
     ROM_END = 0xBFFF
@@ -65,32 +60,27 @@ class Dragon32Cfg(BaseConfig):
     FF00-FFFF I/O, machine configuration, reset vectors
     """
     DEFAULT_ROMS = (
-        ROMFile(address=0x8000, max_size=0x4000,
-            filepath=os.path.join(os.path.abspath(os.path.dirname(__file__)),
-                "d32.rom"
-            )
-        ),
+        Dragon32Rom(address=0x8000, max_size=0x4000),
     )
 
-
     # for unittests init:
-    STARTUP_END_ADDR = 0xbbe5 # scan keyboard
+    STARTUP_END_ADDR = 0xbbe5  # scan keyboard
 
     def __init__(self, cmd_args):
-        super(Dragon32Cfg, self).__init__(cmd_args)
+        super().__init__(cmd_args)
 
         self.machine_api = Dragon32API()
 
         if self.verbosity and self.verbosity <= logging.ERROR:
             self.mem_info = get_dragon_meminfo()
 
-        self.periphery_class = None# Dragon32Periphery
+        self.periphery_class = None  # Dragon32Periphery
 
         self.memory_byte_middlewares = {
             # (start_addr, end_addr): (read_func, write_func)
-#             (0x0152, 0x0159): (None, self.keyboard_matrix_state),
-#             (0x0115, 0x0119): (self.rnd_seed_read, self.rnd_seed_write),
-#             (0x0112, 0x0113): (self.timer_value_read, self.timer_value_write),
+            #             (0x0152, 0x0159): (None, self.keyboard_matrix_state),
+            #             (0x0115, 0x0119): (self.rnd_seed_read, self.rnd_seed_write),
+            #             (0x0112, 0x0113): (self.timer_value_read, self.timer_value_write),
         }
         self.memory_word_middlewares = {
             # (0x0019, 0x001F): (None, self.basic_addresses_write),
@@ -100,7 +90,7 @@ class Dragon32Cfg(BaseConfig):
     def keyboard_matrix_state(self, cpu, addr, value):
         log.critical(
             "%04x|      Set keyboard matrix state $%04x to $%02x %s\t\t\t|%s",
-            cpu.last_op_address, addr, value, '{0:08b}'.format(value),
+            cpu.last_op_address, addr, value, f'{value:08b}',
             self.mem_info.get_shortest(addr)
         )
         # cpu.memory.ram.print_dump(0x004f, 0x0054)
@@ -131,10 +121,10 @@ class Dragon32Cfg(BaseConfig):
         return byte
 
     def basic_addresses_write(self, cycles, last_op_address, address, word):
-#        PROGRAM_START_ADDR = 0x0019
-#        VARIABLES_START_ADDR = 0x001B
-#        ARRAY_START_ADDR = 0x001D
-#        FREE_SPACE_START_ADDR = 0x001F
+        #        PROGRAM_START_ADDR = 0x0019
+        #        VARIABLES_START_ADDR = 0x001B
+        #        ARRAY_START_ADDR = 0x001D
+        #        FREE_SPACE_START_ADDR = 0x001F
         log.critical("%04x| write $%04x to $%04x", last_op_address, word, address)
         return word
 
@@ -143,11 +133,11 @@ class Dragon32Cfg(BaseConfig):
         init the Dragon RAM
         See: http://archive.worldofdragon.org/phpBB3/viewtopic.php?f=5&t=4444
         """
-        mem_FF = [0xff for _ in xrange(4)]
-        mem_00 = [0x00 for _ in xrange(4)]
+        mem_FF = [0xff for _ in range(4)]
+        mem_00 = [0x00 for _ in range(4)]
 
         mem = []
-        for _ in xrange(self.RAM_SIZE // 8):
+        for _ in range(self.RAM_SIZE // 8):
             mem += mem_FF
             mem += mem_00
 
@@ -156,26 +146,8 @@ class Dragon32Cfg(BaseConfig):
     def pia_keymatrix_result(self, inkey, pia0b):
         return get_dragon_keymatrix_pia_result(inkey, pia0b)
 
+
 config = Dragon32Cfg
 
 
-#------------------------------------------------------------------------------
-
-
-def test_run():
-    import sys
-    import os
-    import subprocess
-    cmd_args = [
-        sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-#        "--verbosity", "5",
-        "--machine", "Dragon32", "run",
-#        "--max_ops", "1",
-#        "--trace",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
+# ------------------------------------------------------------------------------
