@@ -1,4 +1,3 @@
-
 """
     DragonPy - Dragon 32 emulator in Python
     =======================================
@@ -21,15 +20,17 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
 
 import logging
 
-log=logging.getLogger(__name__)
-from dragonpy.core.memory_info import BaseMemoryInfo
+from MC6809.core.memory_info import BaseMemoryInfo
+
 from dragonpy.utils.humanize import nice_hex
 
 
+log = logging.getLogger(__name__)
+
+
 class DragonMemInfo(BaseMemoryInfo):
     MEM_INFO = (
         (0x0, 0x0, "BREAK message flag - if negative print BREAK"),
@@ -663,34 +664,34 @@ def get_dragon_meminfo():
 
 
 if __name__ == "__main__":
-#     mem_info = DragonMemInfo(print_out)
-#
-#     # 0xaf-0xaf - TRON/TROFF trace flag - non zero for TRON
-#     mem_info(0xaf)
-#     mem_info(0xaf, shortest=False)
-#     print
-#
-#     # 5x entries
-#     mem_info(0xbff0)
-#     mem_info(0xbff0, shortest=False)
-#     print
-#
-#     # 0xf-0x18 - Temporary results
-#     mem_info(0xf)
-#     mem_info(0xf, shortest=False)
-#     print
-#     mem_info(0x10)
-#     mem_info(0x10, shortest=False)
-#     print
-#     mem_info(0x18)
-#     mem_info(0x18, shortest=False)
-#     print
-#
-#     print "\n --- END --- \n"
+    #     mem_info = DragonMemInfo(print_out)
+    #
+    #     # 0xaf-0xaf - TRON/TROFF trace flag - non zero for TRON
+    #     mem_info(0xaf)
+    #     mem_info(0xaf, shortest=False)
+    #     print
+    #
+    #     # 5x entries
+    #     mem_info(0xbff0)
+    #     mem_info(0xbff0, shortest=False)
+    #     print
+    #
+    #     # 0xf-0x18 - Temporary results
+    #     mem_info(0xf)
+    #     mem_info(0xf, shortest=False)
+    #     print
+    #     mem_info(0x10)
+    #     mem_info(0x10, shortest=False)
+    #     print
+    #     mem_info(0x18)
+    #     mem_info(0x18, shortest=False)
+    #     print
+    #
+    #     print "\n --- END --- \n"
     for s, e, txt in DragonMemInfo.MEM_INFO:
         if s == e:
             addr = nice_hex(s)
         else:
-            addr = "%s-%s" % (nice_hex(s), nice_hex(e))
+            addr = f"{nice_hex(s)}-{nice_hex(e)}"
 
-        print("%-11s ; %s" % (addr, txt))
+        print(f"{addr:<11} ; {txt}")
