@@ -1,24 +1,16 @@
-# coding: utf-8
-
 """
     DragonPy - Dragon 32 emulator in Python
     =======================================
 
     :created: 2014 by Jens Diemer - www.jensdiemer.de
-    :copyleft: 2014 by the DragonPy team, see AUTHORS for more details.
+    :copyleft: 2014-2015 by the DragonPy team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
 
-
-import os
-
-from dragonpy.core.configs import BaseConfig, MULTICOMP6809
-# from dragonpy.Simple6809.mem_info import get_simple6809_meminfo
+from dragonpy.core.configs import MULTICOMP6809, BaseConfig
+from dragonpy.Multicomp6809.Multicomp6809_rom import Multicomp6809Rom
 from dragonpy.Multicomp6809.periphery_Multicomp6809 import Multicomp6809Periphery
-from dragonpy.components.rom import ROMFile
-
 
 
 class Multicomp6809Cfg(BaseConfig):
@@ -30,7 +22,7 @@ class Multicomp6809Cfg(BaseConfig):
     MACHINE_NAME = "Multicomp 6809"
 
     RAM_START = 0x0000
-    RAM_END = 0x03FF # 1KB
+    RAM_END = 0x03FF  # 1KB
     # RAM_END = 0x07FF # 2KB
     # RAM_END = 0x0FFF # 4KB
     # RAM_END = 0x1FFF # 8KB
@@ -54,15 +46,11 @@ class Multicomp6809Cfg(BaseConfig):
     )
 
     DEFAULT_ROMS = (
-        ROMFile(address=0xE000, max_size=0x4000,
-            filepath=os.path.join(os.path.abspath(os.path.dirname(__file__)),
-                "EXT_BASIC_NO_USING.bin"
-            )
-        ),
+        Multicomp6809Rom(address=0xE000, max_size=0x4000),
     )
 
     def __init__(self, cmd_args):
-        super(Multicomp6809Cfg, self).__init__(cmd_args)
+        super().__init__(cmd_args)
 
         self.machine_api = None
 
@@ -81,4 +69,4 @@ if __name__ == "__main__":
     cmd_args = UnittestCmdArgs
     cfg = Multicomp6809Cfg(cmd_args)
     print("RAM Size:", cfg.RAM_SIZE, cfg.RAM_SIZE / 1024)
-    print("RAM End: $%04x" % cfg.RAM_END)
+    print(f"RAM End: ${cfg.RAM_END:04x}")
