@@ -1,23 +1,19 @@
-# coding: utf-8
-
 """
     DragonPy - Dragon 32 emulator in Python
     =======================================
 
-    :created: 2013-2014 by Jens Diemer - www.jensdiemer.de
-    :copyleft: 2013-2014 by the DragonPy team, see AUTHORS for more details.
+    :created: 2013 by Jens Diemer - www.jensdiemer.de
+    :copyleft: 2013-2015 by the DragonPy team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
 
-import os
-
-from dragonpy.Simple6809.mem_info import get_simple6809_meminfo
-from dragonpy.components.rom import ROMFile
-from dragonpy.core.configs import BaseConfig, SIMPLE6809
 from dragonlib.api import CoCoAPI
 
+from dragonpy.core.configs import SIMPLE6809, BaseConfig
+from dragonpy.Simple6809.mem_info import get_simple6809_meminfo
+from dragonpy.Simple6809.Simple6809_rom import Simple6809Rom
+
 
 class Simple6809Cfg(BaseConfig):
     """
@@ -25,9 +21,10 @@ class Simple6809Cfg(BaseConfig):
     More info read ./Simple6809/README.creole
     """
     CONFIG_NAME = SIMPLE6809
+    MACHINE_NAME = "Simple6809"
 
     RAM_START = 0x0000
-    RAM_END = 0x03FF # 1KB
+    RAM_END = 0x03FF  # 1KB
     # RAM_END = 0x07FF # 2KB
     # RAM_END = 0x0FFF # 4KB
 #     RAM_END = 0x1FFF # 8KB
@@ -39,7 +36,7 @@ class Simple6809Cfg(BaseConfig):
     # ROM size is: 0x4000 == 16384 Bytes
 
     RESET_VECTOR = 0xBFFE
-    RESET_VECTOR_VALUE = 0xdb46 # ROM_START + 0x1b46
+    RESET_VECTOR_VALUE = 0xdb46  # ROM_START + 0x1b46
 
     BUS_ADDR_AREAS = (
         (0xa000, 0xbfef, "RS232 interface"),
@@ -47,19 +44,15 @@ class Simple6809Cfg(BaseConfig):
     )
 
     DEFAULT_ROMS = (
-        ROMFile(address=0xC000, max_size=None,
-            filepath=os.path.join(os.path.abspath(os.path.dirname(__file__)),
-                "ExBasROM.bin"
-            )
-        ),
+        Simple6809Rom(address=0xC000, max_size=None),
     )
     # Used in unittest for init the BASIC Interpreter:
-    STARTUP_END_ADDR = 0xdf2b # == JSR  LA390          GO GET AN INPUT LINE
+    STARTUP_END_ADDR = 0xdf2b  # == JSR  LA390          GO GET AN INPUT LINE
 
     def __init__(self, cfg_dict):
-        super(Simple6809Cfg, self).__init__(cfg_dict)
+        super().__init__(cfg_dict)
 
-        self.machine_api = CoCoAPI() # FIXME!
+        self.machine_api = CoCoAPI()  # FIXME!
 
 #         if self.verbosity <= logging.INFO:
         self.mem_info = get_simple6809_meminfo()
@@ -67,12 +60,12 @@ class Simple6809Cfg(BaseConfig):
 #         self.periphery_class = Simple6809Periphery
 
         self.memory_byte_middlewares = {
-#            (0x004f, 0x0054): (None, self.float_accu_write0),
-#            (0x005c, 0x0061): (None, self.float_accu_write1),
+            #            (0x004f, 0x0054): (None, self.float_accu_write0),
+            #            (0x005c, 0x0061): (None, self.float_accu_write1),
         }
 
     def float_accu_write0(self, cpu, addr, value):
-        print("%04x| Write float accu 0 $%x to $%x %s" % (
+        print("{:04x}| Write float accu 0 ${:x} to ${:x} {}".format(
             cpu.last_op_address, value, addr,
             self.mem_info.get_shortest(addr)
         ))
@@ -80,7 +73,7 @@ class Simple6809Cfg(BaseConfig):
         return value
 
     def float_accu_write1(self, cpu, addr, value):
-        print("%04x| Write float accu 1 $%x to $%x %s" % (
+        print("{:04x}| Write float accu 1 ${:x} to ${:x} {}".format(
             cpu.last_op_address, value, addr,
             self.mem_info.get_shortest(addr)
         ))
@@ -89,26 +82,3 @@ class Simple6809Cfg(BaseConfig):
 
 
 config = Simple6809Cfg
-
-
-def test_run():
-    import sys, subprocess
-    cmd_args = [sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-#        "--verbosity=5",
-#         "--verbosity=10", # DEBUG
-#         "--verbosity=20", # INFO
-#        "--verbosity=30", # WARNING
-#         "--verbosity=40", # ERROR
-        "--verbosity=50", # CRITICAL/FATAL
-
-        "--machine=Simple6809",
-#         "--max=500000",
-#         "--max=20000",
-        "--max=1",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
