@@ -19,23 +19,15 @@
     more info, see README
 """
 
-from __future__ import absolute_import, division, print_function
-from dragonlib.utils import six
-xrange = six.moves.xrange
 
 import array
-import os
-import sys
 import logging
 
-from dragonlib.utils import six
-from dragonlib.utils.logging_utils import log_hexlist
-
 
 log = logging.getLogger(__name__)
 
 
-class Memory(object):
+class Memory:
     def __init__(self, cfg, read_bus_request_queue=None, read_bus_response_queue=None, write_bus_queue=None):
         self.cfg = cfg
         self.read_bus_request_queue = read_bus_request_queue
@@ -46,15 +38,24 @@ class Memory(object):
 
         self.RAM_SIZE = (self.cfg.RAM_END - self.cfg.RAM_START) + 1
         self.ROM_SIZE = (self.cfg.ROM_END - self.cfg.ROM_START) + 1
-        assert not hasattr(cfg, "RAM_SIZE"), "cfg.RAM_SIZE is deprecated! Remove it from: %s" % self.cfg.__class__.__name__
-        assert not hasattr(cfg, "ROM_SIZE"), "cfg.ROM_SIZE is deprecated! Remove it from: %s" % self.cfg.__class__.__name__
+        assert not hasattr(cfg, "RAM_SIZE"), (
+            f"cfg.RAM_SIZE is deprecated! Remove it from: {self.cfg.__class__.__name__}"
+        )
+        assert not hasattr(cfg, "ROM_SIZE"), (
+            f"cfg.ROM_SIZE is deprecated! Remove it from: {self.cfg.__class__.__name__}"
+        )
 
-        assert not hasattr(cfg, "ram"), "cfg.ram is deprecated! Remove it from: %s" % self.cfg.__class__.__name__
+        assert not hasattr(cfg, "ram"), (
+            f"cfg.ram is deprecated! Remove it from: {self.cfg.__class__.__name__}"
+        )
 
-        assert not hasattr(cfg, "DEFAULT_ROM"), "cfg.DEFAULT_ROM must be converted to DEFAULT_ROMS tuple in %s" % self.cfg.__class__.__name__
+        assert not hasattr(cfg, "DEFAULT_ROM"), (
+            f"cfg.DEFAULT_ROM must be converted to DEFAULT_ROMS tuple"
+            f" in {self.cfg.__class__.__name__}"
+        )
 
-        assert self.RAM_SIZE + self.RAM_SIZE <= self.INTERNAL_SIZE, "%s Bytes < %s Bytes" % (
-            self.RAM_SIZE + self.RAM_SIZE, self.INTERNAL_SIZE
+        assert self.RAM_SIZE + self.RAM_SIZE <= self.INTERNAL_SIZE, (
+            f"{self.RAM_SIZE + self.RAM_SIZE} Bytes < {self.INTERNAL_SIZE} Bytes"
         )
 
         # About different types of memory see:
@@ -67,7 +68,7 @@ class Memory(object):
 #        self._mem = bytearray(self.cfg.MEMORY_SIZE)
 
         # array consumes also less RAM than lists and it's a little bit faster:
-        self._mem = array.array("B", [0x00] * self.INTERNAL_SIZE) # unsigned char
+        self._mem = array.array("B", [0x00] * self.INTERNAL_SIZE)  # unsigned char
 
         if cfg and cfg.rom_cfg:
             for romfile in cfg.rom_cfg:
@@ -116,25 +117,24 @@ class Memory(object):
 #             "memory write middlewares: %s", self._write_byte_middleware
 #         )
 
-
-        log.critical("init RAM $%04x (dez.:%s) Bytes RAM $%04x (dez.:%s) Bytes (total %s real: %s)",
+        log.critical(
+            "init RAM $%04x (dez.:%s) Bytes RAM $%04x (dez.:%s) Bytes (total %s real: %s)",
             self.RAM_SIZE, self.RAM_SIZE,
             self.ROM_SIZE, self.ROM_SIZE,
             self.RAM_SIZE + self.ROM_SIZE,
             len(self._mem)
         )
 
-
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _map_address_range(self, callbacks_dict, callback_func, start_addr, end_addr=None):
         if end_addr is None:
             callbacks_dict[start_addr] = callback_func
         else:
-            for addr in xrange(start_addr, end_addr + 1):
+            for addr in range(start_addr, end_addr + 1):
                 callbacks_dict[addr] = callback_func
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def add_read_byte_callback(self, callback_func, start_addr, end_addr=None):
         self._map_address_range(self._read_byte_callbacks, callback_func, start_addr, end_addr)
@@ -148,7 +148,7 @@ class Memory(object):
     def add_write_word_callback(self, callback_func, start_addr, end_addr=None):
         self._map_address_range(self._write_word_callbacks, callback_func, start_addr, end_addr)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def add_read_byte_middleware(self, callback_func, start_addr, end_addr=None):
         self._map_address_range(self._read_byte_middleware, callback_func, start_addr, end_addr)
@@ -162,21 +162,20 @@ class Memory(object):
     def add_write_word_middleware(self, callback_func, start_addr, end_addr=None):
         self._map_address_range(self._write_word_middleware, callback_func, start_addr, end_addr)
 
-    #---------------------------------------------------------------------------
-
+    # ---------------------------------------------------------------------------
 
     def load(self, address, data):
-        if isinstance(data, six.string_types):
+        if isinstance(data, str):
             data = [ord(c) for c in data]
 
         log.debug("ROM load at $%04x: %s", address,
-            ", ".join(["$%02x" % i for i in data])
-        )
+                  ", ".join(["$%02x" % i for i in data])
+                  )
         for ea, datum in enumerate(data, address):
             try:
                 self._mem[ea] = datum
             except OverflowError as err:
-                msg="%s - datum=$%x ea=$%04x (load address was: $%04x - data length: %iBytes)" % (
+                msg = "%s - datum=$%x ea=$%04x (load address was: $%04x - data length: %iBytes)" % (
                     err, datum, ea, address, len(data)
                 )
                 raise OverflowError(msg)
@@ -184,9 +183,9 @@ class Memory(object):
     def load_file(self, romfile):
         data = romfile.get_data()
         self.load(romfile.address, data)
-        log.critical("Load ROM file %r to $%04x", romfile.filepath, romfile.address)
+        log.critical("Load ROM file %r to $%04x", romfile.rom_path, romfile.address)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def read_byte(self, address):
         self.cpu.cycles += 1
@@ -195,17 +194,18 @@ class Memory(object):
             byte = self._read_byte_callbacks[address](
                 self.cpu.cycles, self.cpu.last_op_address, address
             )
-            assert byte is not None, "Error: read byte callback for $%04x func %r has return None!" % (
-                address, self._read_byte_callbacks[address].__name__
+            assert byte is not None, (
+                f"Error: read byte callback for ${address:04x} func"
+                f" {self._read_byte_callbacks[address].__name__!r} has return None!"
             )
             return byte
 
         try:
             byte = self._mem[address]
         except KeyError:
-            msg = "reading outside memory area (PC:$%x)" % self.cpu.program_counter.get()
+            msg = f"reading outside memory area (PC:${self.cpu.program_counter.value:x})"
             self.cfg.mem_info(address, msg)
-            msg2 = "%s: $%x" % (msg, address)
+            msg2 = f"{msg}: ${address:x}"
             log.warning(msg2)
             # raise RuntimeError(msg2)
             byte = 0x0
@@ -214,8 +214,9 @@ class Memory(object):
             byte = self._read_byte_middleware[address](
                 self.cpu.cycles, self.cpu.last_op_address, address, byte
             )
-            assert byte is not None, "Error: read byte middleware for $%04x func %r has return None!" % (
-                address, self._read_byte_middleware[address].__name__
+            assert byte is not None, (
+                f"Error: read byte middleware for ${address:04x}"
+                f" func {self._read_byte_middleware[address].__name__!r} has return None!"
             )
 
 #        log.log(5, "%04x| (%i) read byte $%x from $%x",
@@ -229,21 +230,24 @@ class Memory(object):
             word = self._read_word_callbacks[address](
                 self.cpu.cycles, self.cpu.last_op_address, address
             )
-            assert word is not None, "Error: read word callback for $%04x func %r has return None!" % (
-                address, self._read_word_callbacks[address].__name__
+            assert word is not None, (
+                f"Error: read word callback for ${address:04x}"
+                f" func {self._read_word_callbacks[address].__name__!r} has return None!"
             )
             return word
 
         # 6809 is Big-Endian
         return (self.read_byte(address) << 8) + self.read_byte(address + 1)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def write_byte(self, address, value):
         self.cpu.cycles += 1
 
-        assert value >= 0, "Write negative byte hex:%00x dez:%i to $%04x" % (value, value, address)
-        assert value <= 0xff, "Write out of range byte hex:%02x dez:%i to $%04x" % (value, value, address)
+        assert value >= 0, f"Write negative byte hex:{value:00x} dez:{value:d} to ${address:04x}"
+        assert value <= 0xff, (
+            f"Write out of range byte hex:{value:02x} dez:{value:d} to ${address:04x}"
+        )
 #         if not (0x0 <= value <= 0xff):
 #             log.error("Write out of range value $%02x to $%04x", value, address)
 #             value = value & 0xff
@@ -253,8 +257,9 @@ class Memory(object):
             value = self._write_byte_middleware[address](
                 self.cpu.cycles, self.cpu.last_op_address, address, value
             )
-            assert value is not None, "Error: write byte middleware for $%04x func %r has return None!" % (
-                address, self._write_byte_middleware[address].__name__
+            assert value is not None, (
+                f"Error: write byte middleware for ${address:04x}"
+                f" func {self._write_byte_middleware[address].__name__!r} has return None!"
             )
 
         if address in self._write_byte_callbacks:
@@ -263,35 +268,40 @@ class Memory(object):
             )
 
         if self.cfg.ROM_START <= address <= self.cfg.ROM_END:
-            msg = "%04x| writing into ROM at $%04x ignored." % (
-                self.cpu.program_counter.get(), address
+            msg = (
+                f"{self.cpu.program_counter.value:04x}|"
+                f" writing into ROM at ${address:04x} ignored."
             )
             self.cfg.mem_info(address, msg)
-            msg2 = "%s: $%x" % (msg, address)
+            msg2 = f"{msg}: ${address:x}"
             log.critical(msg2)
             return
 
         try:
             self._mem[address] = value
         except (IndexError, KeyError):
-            msg = "%04x| writing to %x is outside RAM/ROM !" % (
-                self.cpu.program_counter.get(), address
+            msg = (
+                f"{self.cpu.program_counter.value:04x}|"
+                f" writing to {address:x} is outside RAM/ROM !"
             )
             self.cfg.mem_info(address, msg)
-            msg2 = "%s: $%x" % (msg, address)
+            msg2 = f"{msg}: ${address:x}"
             log.warning(msg2)
 #             raise RuntimeError(msg2)
 
     def write_word(self, address, word):
-        assert word >= 0, "Write negative word hex:%04x dez:%i to $%04x" % (word, word, address)
-        assert word <= 0xffff, "Write out of range word hex:%04x dez:%i to $%04x" % (word, word, address)
+        assert word >= 0, f"Write negative word hex:{word:04x} dez:{word:d} to ${address:04x}"
+        assert word <= 0xffff, (
+            f"Write out of range word hex:{word:04x} dez:{word:d} to ${address:04x}"
+        )
 
         if address in self._write_word_middleware:
             word = self._write_word_middleware[address](
                 self.cpu.cycles, self.cpu.last_op_address, address, word
             )
-            assert word is not None, "Error: write word middleware for $%04x func %r has return None!" % (
-                address, self._write_word_middleware[address].__name__
+            assert word is not None, (
+                f"Error: write word middleware for ${address:04x}"
+                f" func {self._write_word_middleware[address].__name__!r} has return None!"
             )
 
         if address in self._write_word_callbacks:
@@ -303,51 +313,27 @@ class Memory(object):
         self.write_byte(address, word >> 8)
         self.write_byte(address + 1, word & 0xff)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def get(self, start, end):
         """
         used in unittests
         """
-        return [self.read_byte(addr) for addr in xrange(start, end)]
+        return [self.read_byte(addr) for addr in range(start, end)]
 
     def iter_bytes(self, start, end):
-        for addr in xrange(start, end):
+        for addr in range(start, end):
             yield addr, self.read_byte(addr)
 
     def get_dump(self, start, end):
         dump_lines = []
         for addr, value in self.iter_bytes(start, end):
-            msg = "$%04x: $%02x (dez: %i)" % (addr, value, value)
-            msg = "%-25s| %s" % (
-                msg, self.cfg.mem_info.get_shortest(addr)
-            )
+            msg = f"${addr:04x}: ${value:02x} (dez: {value:d})"
+            msg = f"{msg:<25}| {self.cfg.mem_info.get_shortest(addr)}"
             dump_lines.append(msg)
         return dump_lines
 
     def print_dump(self, start, end):
-        print("Memory dump from $%04x to $%04x:" % (start, end))
+        print(f"Memory dump from ${start:04x} to ${end:04x}:")
         dump_lines = self.get_dump(start, end)
         print("\n".join(["\t%s" % line for line in dump_lines]))
-
-
-def test_run():
-    import subprocess
-    cmd_args = [sys.executable,
-        "DragonPy_CLI.py",
-#         "--verbosity=5",
-#         "--verbosity=10",
-#         "--verbosity=20",
-#         "--verbosity=30",
-#         "--verbosity=40",
-        "--verbosity=50",
-        "--machine=Simple6809",
-#         "--max=100000",
-#         "--max=30000",
-#         "--max=20000",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
