@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     DragonPy - Dragon 32 emulator in Python
     =======================================
@@ -9,13 +7,11 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-from dragonlib.utils import six
-xrange = six.moves.xrange
 
 import inspect
 import logging
 
+
 log = logging.getLogger(__name__)
 
 
@@ -30,18 +26,21 @@ VECTREX = "Vectrex"
 
 class MachineDict(dict):
     DEFAULT = None
+
     def register(self, name, cls, default=False):
         dict.__setitem__(self, name, cls)
         if default:
             assert self.DEFAULT is None
             self.DEFAULT = name
 
+
 machine_dict = MachineDict()
 
 
-class DummyMemInfo(object):
+class DummyMemInfo:
     def get_shortest(self, *args):
         return ">>mem info not active<<"
+
     def __call__(self, *args):
         return ">>mem info not active<<"
 
@@ -54,20 +53,21 @@ class AddressAreas(dict):
         Text screen
         Serial/parallel devices
     """
+
     def __init__(self, areas):
-        super(AddressAreas, self).__init__()
+        super().__init__()
         for start_addr, end_addr, txt in areas:
             self.add_area(start_addr, end_addr, txt)
 
     def add_area(self, start_addr, end_addr, txt):
-        for addr in xrange(start_addr, end_addr + 1):
+        for addr in range(start_addr, end_addr + 1):
             dict.__setitem__(self, addr, txt)
 
 
-class BaseConfig(object):
-#     # http address/port number for the CPU control server
-#     CPU_CONTROL_ADDR = "127.0.0.1"
-#     CPU_CONTROL_PORT = 6809
+class BaseConfig:
+    #     # http address/port number for the CPU control server
+    #     CPU_CONTROL_ADDR = "127.0.0.1"
+    #     CPU_CONTROL_PORT = 6809
 
     # How many ops should be execute before make a control server update cycle?
     BURST_COUNT = 10000
@@ -76,7 +76,7 @@ class BaseConfig(object):
 
     def __init__(self, cfg_dict):
         self.cfg_dict = cfg_dict
-        self.cfg_dict["cfg_module"] = self.__module__ # FIXME: !
+        self.cfg_dict["cfg_module"] = self.__module__  # FIXME: !
 
         log.debug("cfg_dict: %s", repr(cfg_dict))
 
@@ -88,7 +88,8 @@ class BaseConfig(object):
 #         else:
 #             self.bus = None # Will be set in cpu6809.start_CPU()
 
-        assert not hasattr(cfg_dict, "ram"), "cfg_dict.ram is deprecated! Remove it from: %s" % self.cfg_dict.__class__.__name__
+        assert not hasattr(
+            cfg_dict, "ram"), f"cfg_dict.ram is deprecated! Remove it from: {self.cfg_dict.__class__.__name__}"
 
 #         if cfg_dict["rom"]:
 #             raw_rom_cfg = cfg_dict["rom"]
@@ -123,39 +124,15 @@ class BaseConfig(object):
 #         self._mem = [0x00] * size
 
     def print_debug_info(self):
-        print("Config: '%s'" % self.__class__.__name__)
+        print(f"Config: '{self.__class__.__name__}'")
 
-        for name, value in inspect.getmembers(self): # , inspect.isdatadescriptor):
+        for name, value in inspect.getmembers(self):  # , inspect.isdatadescriptor):
             if name.startswith("_"):
                 continue
 #             print name, type(value)
             if not isinstance(value, (int, str, list, tuple, dict)):
                 continue
             if isinstance(value, int):
-                print("%20s = %-6s in hex: %7s" % (
-                    name, value, hex(value)
-                ))
+                print(f"{name:>20} = {value:<6} in hex: {hex(value):>7}")
             else:
-                print("%20s = %s" % (name, value))
-
-
-def test_run():
-    import os, sys, subprocess
-    cmd_args = [sys.executable,
-        os.path.join("..", "..", "DragonPy_CLI.py"),
-
-#         "--verbosity=5",
-        "--verbosity=10", # DEBUG
-#         "--verbosity=20", # INFO
-#         "--verbosity=30", # WARNING
-#         "--verbosity=40", # ERROR
-#         "--verbosity=50", # CRITICAL/FATAL
-
-#         "--machine=Simple6809",
-        "--machine=sbc09",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd=".").wait()
-
-if __name__ == "__main__":
-    test_run()
+                print(f"{name:>20} = {value}")
