@@ -1,4 +1,3 @@
-
 """
     Hacked script to create a *short* trace
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -11,30 +10,30 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
 
-
-from functools import partial
 import os
 import subprocess
 import sys
 import tempfile
 import threading
 import time
+from functools import partial
+
+from MC6809.components.MC6809data.MC6809_data_utils import MC6809OP_DATA_DICT
 
-from dragonpy.components.MC6809data.MC6809_data_utils import MC6809OP_DATA_DICT
-from dragonpy.utils.humanize import cc_value2txt
 from dragonpy.sbc09.mem_info import SBC09MemInfo
+from dragonpy.utils.humanize import cc_value2txt
 
 
 def proc_killer(proc, timeout):
     time.sleep(timeout)
     if proc.poll() is None:
-        print("kill process after %fsec timeout..." % timeout)
+        print(f"kill process after {timeout:f}sec timeout...")
         proc.kill()
 
+
 def subprocess2(timeout=3, **kwargs):
-    print("Start: %s" % " ".join(kwargs["args"]))
+    print(f"Start: {' '.join(kwargs['args'])}")
     proc = subprocess.Popen(**kwargs)
     threading.Thread(target=partial(proc_killer, proc, timeout)).start()
     return proc
@@ -44,21 +43,21 @@ def create_v09_trace(commands, timeout, max_newlines=None):
     trace_file = tempfile.NamedTemporaryFile()
 
     proc = subprocess2(timeout=timeout,
-        args=("./v09", "-t", trace_file.name),
-        cwd="sbc09",
-        stdin=subprocess.PIPE,
-        stdout=subprocess.PIPE,
-    )
-    print("Started with timeout: %fsec." % timeout)
+                       args=("./v09", "-t", trace_file.name),
+                       cwd="sbc09",
+                       stdin=subprocess.PIPE,
+                       stdout=subprocess.PIPE,
+                       )
+    print(f"Started with timeout: {timeout:f}sec.")
 
     commands = "".join(["%s\n" % cmd for cmd in commands])
-    print("Commands: %r" % commands)
+    print(f"Commands: {commands!r}")
     proc.stdin.write(commands)
     proc.stdin.flush()
 
     print()
     print("Process output:")
-    print("-"*79)
+    print("-" * 79)
     newline_count = 0
     line_buffer = ""
     while proc.poll() is None:
@@ -67,7 +66,7 @@ def create_v09_trace(commands, timeout, max_newlines=None):
             print(line_buffer)
             newline_count += 1
             if max_newlines is not None and newline_count >= max_newlines:
-                print("Aboad process after %i newlines." % newline_count)
+                print(f"Aboad process after {newline_count:d} newlines.")
                 proc.kill()
                 break
             line_buffer = ""
@@ -76,8 +75,8 @@ def create_v09_trace(commands, timeout, max_newlines=None):
         else:
             line_buffer += char
 
-    print("-"*79)
-    print("Process ends and output %i newlines." % newline_count)
+    print("-" * 79)
+    print(f"Process ends and output {newline_count:d} newlines.")
     print()
 
     result = trace_file.read()
@@ -103,13 +102,13 @@ def reformat_v09_trace(raw_trace, max_lines=None):
     old_line = None
     for line_no, line in enumerate(raw_trace.splitlines()):
         if max_lines is not None and line_no >= max_lines:
-            msg = "max lines %i arraived -> Abort." % max_lines
+            msg = f"max lines {max_lines:d} arraived -> Abort."
             print(msg)
             result.append(msg)
             break
 
         if time.time() > next_update:
-            print("reformat %i trace lines..." % line_no)
+            print(f"reformat {line_no:d} trace lines...")
             next_update = time.time() + 1
 
         try:
@@ -123,11 +122,11 @@ def reformat_v09_trace(raw_trace, max_lines=None):
             u = int(line[32:36], 16)
             s = int(line[39:43], 16)
         except ValueError as err:
-            print("Error in line %i: %s" % (line_no, err))
-            print("Content on line %i:" % line_no)
-            print("-"*79)
+            print(f"Error in line {line_no:d}: {err}")
+            print(f"Content on line {line_no:d}:")
+            print("-" * 79)
             print(repr(line))
-            print("-"*79)
+            print("-" * 79)
             continue
 
         op_data = MC6809OP_DATA_DICT[op_code]
@@ -137,59 +136,53 @@ def reformat_v09_trace(raw_trace, max_lines=None):
         mem = mem_info.get_shortest(pc)
 #        print op_data
 
-        register_line = "cc=%02x a=%02x b=%02x dp=?? x=%04x y=%04x u=%04x s=%04x| %s" % (
-            cc, a, b, x, y, u, s, cc_txt
-        )
+        register_line = f"cc={cc:02x} a={a:02x} b={b:02x} dp=?? x={x:04x} y={y:04x} u={u:04x} s={s:04x}| {cc_txt}"
         if old_line is None:
-            line = "(init with: %s)" % register_line
+            line = f"(init with: {register_line})"
         else:
             line = old_line % register_line
 
-        old_line = "%04x| %-11s %-27s %%s | %s" % (
-            pc, "%x" % op_code, mnemonic,
-            mem
-        )
+        old_line = f"{pc:04x}| {f'{op_code:x}':<11} {mnemonic:<27} %s | {mem}"
 
         result.append(line)
 
-    print("Done, %i trace lines converted." % line_no)
+    print(f"Done, {line_no:d} trace lines converted.")
 #    print raw_trace[:700]
     return result
 
 
 if __name__ == '__main__':
     commands = [
-        "H100+F", # Calculate simple expression in hex with + and -
+        "H100+F",  # Calculate simple expression in hex with + and -
 
-#        "r", # Register display
-#        "ss", # generate Motorola S records
+        #        "r", # Register display
+        #        "ss", # generate Motorola S records
 
-#        "XL400", # Load binary data using X-modem protocol at $400
-#        "\x1d" # escape character
-#        "ubasic", # load the binary file "basic" at address $400
+        #        "XL400", # Load binary data using X-modem protocol at $400
+        #        "\x1d" # escape character
+        #        "ubasic", # load the binary file "basic" at address $400
 
-#        "UE400,20" # Diassemble first 32 bytes of monitor program.
+        #        "UE400,20" # Diassemble first 32 bytes of monitor program.
 
-        #"\x1d" # escape character FIXME: Doesn't work :(
-        #"x", # exit
+        # "\x1d" # escape character FIXME: Doesn't work :(
+        # "x", # exit
     ]
 
     raw_trace = create_v09_trace(commands,
-        timeout=0.1,
-        max_newlines=3 # Close process after X newlines
-#        max_newlines=None # No limit
-    )
+                                 timeout=0.1,
+                                 max_newlines=3  # Close process after X newlines
+                                 #        max_newlines=None # No limit
+                                 )
 #    print raw_trace
     trace = reformat_v09_trace(raw_trace,
-#        max_lines=15
-        max_lines=None # All lines
-    )
+                               #        max_lines=15
+                               max_lines=None  # All lines
+                               )
 #    print "\n".join(trace)
 
     out_filename = os.path.abspath("../v09_trace.txt")
     with open(out_filename, "w") as f:
         f.write("\n".join(trace))
 
-    print("Trace file %r created." % out_filename)
+    print(f"Trace file {out_filename!r} created.")
     print(" --- END --- ")
-
