@@ -1,5 +1,3 @@
-# encoding:utf8
-
 """
     DragonPy
     ========
@@ -16,13 +14,11 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-from dragonlib.utils import six
-xrange = six.moves.xrange
 
 import logging
 
-log=logging.getLogger(__name__)
+
+log = logging.getLogger(__name__)
 
 
 VECTREX_MHZ = 1500000
@@ -32,14 +28,14 @@ VECTOR_HASH = 65521
 
 ALG_MAX_X = 33000
 ALG_MAX_Y = 41000
-SCREEN_X_DEFAULT = 330 # in pixel
-SCREEN_Y_DEFAULT = 410 # in pixel
+SCREEN_X_DEFAULT = 330  # in pixel
+SCREEN_Y_DEFAULT = 410  # in pixel
 
 FCYCLES_INIT = VECTREX_MHZ // VECTREX_PDECAY >> 0
 VECTOR_CNT = VECTREX_MHZ // VECTREX_PDECAY >> 0
 
 
-class MOS6522VIA(object):
+class MOS6522VIA:
     """
     MOS Technology 6522 Versatile Interface Adapter (VIA)
 
@@ -48,6 +44,7 @@ class MOS6522VIA(object):
     $D000 - $D7FF 6522 interface adapter
     $D800 - $DFFF 6522 / RAM ?!?
     """
+
     def __init__(self, cfg, memory):
         self.cfg = cfg
         self.memory = memory
@@ -68,7 +65,7 @@ class MOS6522VIA(object):
 
     def reset(self):
         self.snd_regs = {}
-        for i in xrange(16):
+        for i in range(16):
             self.snd_regs[i] = 0
         self.snd_regs[14] = 0xff
 
@@ -132,7 +129,7 @@ class MOS6522VIA(object):
         self.write8(address, value)
         log.error("%04x| TODO: 6522 write $%02x to $%04x", op_address, value, address)
 
-    def snd_update (self):
+    def snd_update(self):
         switch_orb = self.via_orb & 0x18
         if switch_orb == 0x10:
             if(self.snd_select != 14):
@@ -240,7 +237,7 @@ class MOS6522VIA(object):
 
         return 0xff
 
-    def write8 (self, address, data):
+    def write8(self, address, data):
         switch_addr = address & 0xf
         if switch_addr == 0x0:
             self.via_orb = data
@@ -326,23 +323,4 @@ class MOS6522VIA(object):
                 self.via_ifr &= 0x7f
 
 
-#------------------------------------------------------------------------------
-
-
-def test_run():
-    import sys
-    import os
-    import subprocess
-    cmd_args = [
-        sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-        "--verbosity", "5",
-        "--machine", "Vectrex", "run",
-        "--max_ops", "1",
-        "--trace",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
+# ------------------------------------------------------------------------------
