@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     DragonPy - Vectrex
     ==================
@@ -11,18 +9,15 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
-
-import logging
-import os
 
 import logging
 
-log=logging.getLogger(__name__)
-from dragonpy.components.rom import ROMFile
-from dragonpy.core.configs import BaseConfig, VECTREX
+from dragonpy.core.configs import VECTREX, BaseConfig
 from dragonpy.vectrex.mem_info import VectrexMemInfo
+from dragonpy.vectrex.vectrex_rom import VectrexRom
+
+
+log = logging.getLogger(__name__)
 
 
 # from dragonlib.api import VectrexAPI
@@ -46,13 +41,11 @@ class VectrexCfg(BaseConfig):
 
     ROM_START = 0xE000
     ROM_END = 0xFFFF
-    ROM_SIZE = 0x2000
 
     DEFAULT_ROMS = (
-        ROMFile(address=0xE000, # max_size=0x4000,
-            filepath=os.path.join(os.path.abspath(os.path.dirname(__file__)),
-                "SYSTEM.IMG"
-            )
+        VectrexRom(
+            address=0xE000,
+            # max_size=0x4000
         ),
     )
 
@@ -60,13 +53,11 @@ class VectrexCfg(BaseConfig):
     # STARTUP_END_ADDR = 0xbbe5 # scan keyboard
 
     def __init__(self, cmd_args):
-        self.ROM_SIZE = (self.ROM_END - self.ROM_START) + 1
-        self.RAM_SIZE = (self.RAM_END - self.RAM_START) + 1
-        super(VectrexCfg, self).__init__(cmd_args)
+        super().__init__(cmd_args)
 
-        self.machine_api = None# VectrexAPI()
+        self.machine_api = None  # VectrexAPI()
 
-        self.periphery_class = None# VectrexPeriphery
+        self.periphery_class = None  # VectrexPeriphery
 
         # TODO:
         # http://www.playvectrex.com/designit/chrissalo/appendixa.htm#Other
@@ -77,23 +68,4 @@ class VectrexCfg(BaseConfig):
 config = VectrexCfg
 
 
-#------------------------------------------------------------------------------
-
-
-def test_run():
-    import sys
-    import os
-    import subprocess
-    cmd_args = [
-        sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-        "--verbosity", "5",
-        "--machine", "Vectrex", "run",
-        "--max_ops", "1",
-        "--trace",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
+# ------------------------------------------------------------------------------
