@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# encoding:utf8
 
 """
     DragonPy
@@ -10,25 +9,23 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
-
-import os
-import sys
 
 import logging
 
-log=logging.getLogger(__name__)
 from dragonpy.components.periphery import PeripheryBase
 from dragonpy.vectrex.MOS6522 import MOS6522VIA
 
 
+log = logging.getLogger(__name__)
+
+
 class VectrexPeripheryBase(PeripheryBase):
     """
     GUI independent stuff
     """
-    def __init__(self, cfg, memory, user_input_queue):
-        super(VectrexPeripheryBase, self).__init__(cfg, memory, user_input_queue)
+
+    def __init__(self, cfg, cpu, memory, display_queue=None, user_input_queue=None):
+        super().__init__(cfg, cpu, memory, display_queue, user_input_queue)
 
         self.via = MOS6522VIA(cfg, memory)
 
@@ -51,29 +48,10 @@ class VectrexPeripheryBase(PeripheryBase):
 
 
 class VectrexPeriphery(VectrexPeripheryBase):
-    def __init__(self, cfg, memory, display_queue, user_input_queue):
-        super(VectrexPeriphery, self).__init__(cfg, memory, user_input_queue)
+    def __init__(self, cfg, cpu, memory, display_queue=None, user_input_queue=None):
+        super().__init__(cfg, cpu, memory, display_queue, user_input_queue)
 
         # redirect writes to display RAM area 0x0400-0x0600 into display_queue:
-        #DragonDisplayOutputHandler(display_queue, memory)
+        # DragonDisplayOutputHandler(display_queue, memory)
 
-#------------------------------------------------------------------------------
-
-
-def test_run():
-    import sys
-    import os
-    import subprocess
-    cmd_args = [
-        sys.executable,
-        os.path.join("..", "DragonPy_CLI.py"),
-        "--verbosity", "5",
-        "--machine", "Vectrex", "run",
-        "--max_ops", "1",
-        "--trace",
-    ]
-    print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
-    subprocess.Popen(cmd_args, cwd="..").wait()
-
-if __name__ == "__main__":
-    test_run()
+# ------------------------------------------------------------------------------
